@@ -9,11 +9,11 @@ if __name__ == '__main__':
     subparsers = parser.add_subparsers(dest="command", title="Available commands")
     subparsers.required = True
     pyhackrf_info_parser = subparsers.add_parser(
-    'info', help='Read device information from HackRF such as serial number and firmware version.', usage="python -m python_hackrf info [-h] [-f] [-s]"
+        'info', help='Read device information from HackRF such as serial number and firmware version.', usage="python -m python_hackrf info [-h] [-f] [-s]"
     )
     pyhackrf_info_parser.add_argument('-f', '--full', action='store_true', help='show info like in hackrf_info')
     pyhackrf_info_parser.add_argument('-s', '--serial_numbers', action='store_true', help='show only founded serial_numbers')
-    
+
     pyhackrf_sweep_parser = subparsers.add_parser(
         'sweep', help='a command-line spectrum analyzer.', usage='python -m python_hackrf sweep [-h] [-d] [-a] [-f] [-p] [-l] [-g] [-w] [-1] [-N] [-I] [-r]'
     )
@@ -44,11 +44,11 @@ if __name__ == '__main__':
             freq_min, freq_max = None, None
             try:
                 freq_min = int(frequency_range[0])
-            except:
+            except Exception:
                 pass
             try:
                 freq_max = int(frequency_range[1])
-            except:
+            except Exception:
                 pass
             if freq_min is not None and freq_max is not None:
                 frequencies.extend([freq_min, freq_max])
